@@ -23,41 +23,37 @@ try:
 except ImportError:
     mpd = None
 
-import nowplaying.players
-import nowplaying.players.__mpris__
-import nowplaying.players.__mpd__
+import __mpd__, __mpris__
 
 def _get_players():
-    players_path = nowplaying.players.__path__[0]
+    path = "/usr/share/python-nowplaying/players/"
+    #path = "../players/"   # for debugging
     
     players = []
-    
-    for path in glob.glob(players_path + "/*.py"):
+    for g in glob.glob(path + "*"):
+        g = os.path.basename(g)
         
-        name = os.path.basename(path)[:-3]
-        if name.startswith("__"): continue
+        if g.startswith("__"): continue
         
-        full_name = "%s.players.%s" %(__package__, name)
-        
-        if not full_name in sys.modules.keys():
-            imp.load_module(full_name, *imp.find_module(name, [players_path]))
-        
-        players.append(sys.modules[full_name].Player())
+        name = g[:-3]
+        data = imp.find_module(name, [path])
+        module = imp.load_module(name, *data)
+        players += [module.Player]
     
     return players
 
+_defined_players = _get_players()
+
 def _get_mpris_players():
     bus = dbus.SessionBus()
     
     players = []
     for name in bus.list_activatable_names():
         if name.startswith("org.mpris."):
-            players.append(nowplaying.players.__mpris__.Player(name))
+            players.append(__mpris__.Player(name))
     
     return players
 
-_defined_players = _get_players()
-
 def _get_mpd_default():
     """ Returns a (hostname, port) from the environ variable if set """
     
@@ -75,7 +71,7 @@ def _get_mpd_default():
 _default_mpd = _get_mpd_default()
 
 def get_mpd_player(host=_default_mpd[0], port=_default_mpd[1]):
-    p = nowplaying.players.__mpd__.Player(host, port)
+    p = __mpd__.Player(host, port)
     
     if p.is_running():
         return p
